Skip to contents

Queries the RIDE Data Center metadata API and compares available files against the hardcoded file catalog. Reports any new files that aren't yet in the catalog.

Usage

check_for_updates()

Value

Invisibly returns a data frame of new files (if any). Prints a summary message to the console.

Examples

if (FALSE) { # \dontrun{
check_for_updates()
} # }