Skip to contents

Queries the RIDE Data Center metadata API to find enrollment files that aren't in the hardcoded catalog. Useful for maintainers to discover when new data has been uploaded.

Usage

ride_detect_new_files()

Value

Data frame of files found on RIDE, with a column indicating whether each file is already in the catalog

Examples

if (FALSE) { # \dontrun{
new_files <- ride_detect_new_files()
new_files[!new_files$in_catalog, ]
} # }